@@ -6,8 +6,8 @@ coef.CARBayes <- function(object,...)
         return(NULL)  
     }else
     {
-    beta <- apply(object$samples$beta, 2, median)
-    names(beta) <- colnames(object$X)    
+    beta <- apply(object$samples$beta, 2, mean)
+    names(beta) <- rownames(object$summary.results)[1:length(beta)]
     return(beta)
     }
-}
\ No newline at end of file
+}
