@@ -1,4 +1,4 @@
-gaussian.multilevelCAR <- function(formula, data=NULL, W, ind.area, ind.re=NULL, burnin, n.sample, thin=1, prior.mean.beta=NULL, prior.var.beta=NULL, prior.nu2=NULL, prior.tau2=NULL, prior.sigma2=NULL, rho=NULL, verbose=TRUE)
+gaussian.multilevelCAR <- function(formula, data=NULL, W, ind.area, burnin, n.sample, thin=1, prior.mean.beta=NULL, prior.var.beta=NULL, prior.nu2=NULL, prior.tau2=NULL, rho=NULL, verbose=TRUE)
 {
 ##############################################
 #### Format the arguments and check for errors
@@ -75,37 +75,14 @@ n.individual <- rep(0,K)
     }
 
 
-#### Checks and formatting for ind.re
-    if(!is.null(ind.re))
-    {
-        if(!is.factor(ind.re)) stop("ind.re is not a factor.", call.=FALSE)
-    ind.re.unique <- levels(ind.re)
-    q <- length(ind.re.unique)
-    ind.re.list <- as.list(rep(NA,q))
-    ind.re.num <- rep(NA, n)
-        for(r in 1:q)
-        {
-        which.re.ind <- which(ind.re==ind.re.unique[r])
-        ind.re.list[[r]] <- which.re.ind
-        ind.re.num[which.re.ind] <- r
-        }
-    n.re <- as.numeric(lapply(ind.re.list,length))
-    }else
-    {
-    cat("There are no individual level effects in this model\n")    
-    }
-
-
 #### Priors
     if(is.null(prior.mean.beta)) prior.mean.beta <- rep(0, p)
     if(is.null(prior.var.beta)) prior.var.beta <- rep(100000, p)
     if(is.null(prior.tau2)) prior.tau2 <- c(1, 0.01)
     if(is.null(prior.nu2)) prior.nu2 <- c(1, 0.01)
-    if(is.null(prior.sigma2)) prior.sigma2 <- c(1, 0.01)   
 common.prior.beta.check(prior.mean.beta, prior.var.beta, p)
 common.prior.var.check(prior.tau2)    
 common.prior.var.check(prior.nu2)  
-common.prior.var.check(prior.sigma2)  
 
 
 #### MCMC quantities - burnin, n.sample, thin
@@ -128,16 +105,7 @@ phi <- rnorm(n=K, mean=rep(0,K), sd=res.sd)
 phi.extend <- phi[ind.area]
 tau2 <- var(phi) / 10
 nu2 <- tau2
-    if(!is.null(ind.re))
-    {
-    psi <- rnorm(n=q, mean=rep(0,q), sd=res.sd/5)
-    psi.extend <- psi[ind.re.num]
-    sigma2 <- var(psi) / 10
-    }else
-    {
-    psi.extend <- rep(0, n)
-    }
-fitted <- as.numeric(X.standardised %*% beta) + phi.extend + offset + psi.extend
+fitted <- as.numeric(X.standardised %*% beta) + phi.extend + offset
 
     
  
@@ -150,8 +118,6 @@ samples.beta <- array(NA, c(n.keep, p))
 samples.phi <- array(NA, c(n.keep, K))
 samples.nu2 <- array(NA, c(n.keep, 1))
 samples.tau2 <- array(NA, c(n.keep, 1))
-    if(!is.null(ind.re)) samples.psi <- array(NA, c(n.keep, q))
-    if(!is.null(ind.re)) samples.sigma2 <- array(NA, c(n.keep, 1))
     if(!fix.rho) samples.rho <- array(NA, c(n.keep, 1))
 samples.loglike <- array(NA, c(n.keep, n))
 samples.fitted <- array(NA, c(n.keep, n))
@@ -163,7 +129,6 @@ accept <- rep(0,2)
 proposal.sd.rho <- 0.02
 tau2.posterior.shape <- prior.tau2[1] + 0.5*K
 nu2.posterior.shape <- prior.nu2[1] + 0.5*n
-    if(!is.null(ind.re)) sigma2.posterior.shape <- prior.sigma2[1] + 0.5 * q 
     
  
 #### Check for islands
@@ -222,7 +187,7 @@ data.precision.beta <- t(X.standardised) %*% X.standardised
     ####################
     fc.precision <- prior.precision.beta + data.precision.beta / nu2
     fc.var <- solve(fc.precision)
-    beta.offset <- as.numeric(Y.DA - offset - phi.extend - psi.extend)
+    beta.offset <- as.numeric(Y.DA - offset - phi.extend)
     beta.offset2 <- t(X.standardised) %*% beta.offset / nu2 + prior.precision.beta %*% prior.mean.beta
     fc.mean <- fc.var %*% beta.offset2
     chol.var <- t(chol(fc.var))
@@ -233,7 +198,7 @@ data.precision.beta <- t(X.standardised) %*% X.standardised
     ##################
     ## Sample from nu2
     ##################
-    fitted.current <-  as.numeric(X.standardised %*% beta) + phi.extend + offset + psi.extend
+    fitted.current <-  as.numeric(X.standardised %*% beta) + phi.extend + offset
     nu2.posterior.scale <- prior.nu2[2] + 0.5 * sum((Y.DA - fitted.current)^2)
     nu2 <- 1 / rgamma(1, nu2.posterior.shape, scale=(1/nu2.posterior.scale))    
         
@@ -242,7 +207,7 @@ data.precision.beta <- t(X.standardised) %*% X.standardised
     ####################
     ## Sample from phi
     ####################
-    offset.phi <- (Y.DA - as.numeric(X.standardised %*% beta) - offset - psi.extend) / nu2
+    offset.phi <- (Y.DA - as.numeric(X.standardised %*% beta) - offset) / nu2
     offset.phi2 <- tapply(offset.phi, ind.area, sum, na.rm=T)
     phi <- gaussiancarmultilevelupdate(Wtriplet=W.triplet, Wbegfin=W.begfin, W.triplet.sum, n_individual=n.individual, nsites=K, phi=phi, tau2=tau2, rho=rho, nu2=nu2, offset=offset.phi2)
         if(rho<1)
@@ -256,27 +221,6 @@ data.precision.beta <- t(X.standardised) %*% X.standardised
         
         
         
-    #############################
-    ## Sample from psi and sigma2
-    #############################
-        if(!is.null(ind.re))
-        {
-        #### Update psi 
-        offset.psi <- (Y.DA - as.numeric(X.standardised %*% beta) - offset - phi.extend) / nu2
-        offset.psi2 <- tapply(offset.psi, ind.re, sum, na.rm=T)
-        temp1b <-  gaussiancarmultilevelupdateindiv(ind_re_list=ind.re.list, n_re=n.re, q=q, psi=psi, sigma2=sigma2, nu2=nu2, offset=offset.psi2)
-        psi <- temp1b - mean(temp1b)
-        psi.extend <- psi[ind.re.num]   
-        
-        
-        #### Update sigma2 
-        sigma2.posterior.scale <- 0.5 * sum(psi^2) + prior.sigma2[2] 
-        sigma2 <- 1 / rgamma(1, sigma2.posterior.shape, scale=(1/sigma2.posterior.scale))
-        }else
-        {}
-    
-        
-        
     ##################
     ## Sample from tau2
     ##################
@@ -316,7 +260,7 @@ data.precision.beta <- t(X.standardised) %*% X.standardised
     #########################
     ## Calculate the deviance
     #########################
-    fitted <- as.numeric(X.standardised %*% beta) + phi.extend + offset + psi.extend
+    fitted <- as.numeric(X.standardised %*% beta) + phi.extend + offset 
     loglike <- dnorm(Y, mean = fitted, sd = rep(sqrt(nu2),n), log=TRUE)
 
         
@@ -330,8 +274,6 @@ data.precision.beta <- t(X.standardised) %*% X.standardised
         samples.phi[ele, ] <- phi
         samples.nu2[ele, ] <- nu2
         samples.tau2[ele, ] <- tau2
-            if(!is.null(ind.re))  samples.psi[ele, ] <- psi
-            if(!is.null(ind.re)) samples.sigma2[ele, ] <- sigma2
             if(!fix.rho) samples.rho[ele, ] <- rho
         samples.loglike[ele, ] <- loglike
         samples.fitted[ele, ] <- fitted
@@ -387,32 +329,15 @@ data.precision.beta <- t(X.standardised) %*% X.standardised
     {
     accept.rho <- NA    
     }
-    if(!is.null(ind.re))
-    {
-    accept.psi <- 100 * accept[7] / accept[8]
-    accept.sigma2 <- 100
-    }else
-    {
-    accept.psi <- NA
-    accept.sigma2 <- NA
-    }
-accept.final <- c(rep(100, 2), accept.psi, 100, 100, accept.rho, accept.sigma2)
-names(accept.final) <- c("beta", "phi", "psi", "nu2", "tau2", "rho", "sigma2")
+accept.final <- c(rep(100, 2),  100, 100, accept.rho)
+names(accept.final) <- c("beta", "phi",  "nu2", "tau2", "rho")
   
     
 #### Compute the fitted deviance
 mean.beta <- apply(samples.beta, 2, mean)
 mean.phi <- apply(samples.phi, 2, mean)
 mean.phi.extend <-  mean.phi[ind.area]
-    if(!is.null(ind.re))
-    {
-    mean.psi <- apply(samples.psi, 2, mean)
-    mean.psi.extend <-  mean.psi[ind.re.num]
-    }else
-    {
-    mean.psi.extend <- rep(0,n)
-    }
-fitted.mean <- X.standardised %*% mean.beta + mean.phi.extend + mean.psi.extend + offset
+fitted.mean <- X.standardised %*% mean.beta + mean.phi.extend + offset
 nu2.mean <- mean(samples.nu2)
 deviance.fitted <- -2 * sum(dnorm(Y, mean = fitted.mean, sd = rep(sqrt(nu2.mean),n), log = TRUE), na.rm=TRUE)
 
@@ -427,41 +352,31 @@ samples.beta.orig <- common.betatransform(samples.beta, X.indicator, X.mean, X.s
     
 #### Create a summary object
 samples.beta.orig <- mcmc(samples.beta.orig)
-summary.beta <- t(apply(samples.beta.orig, 2, quantile, c(0.5, 0.025, 0.975))) 
+summary.beta <- t(rbind(apply(samples.beta.orig, 2, mean), apply(samples.beta.orig, 2, quantile, c(0.025, 0.975)))) 
 summary.beta <- cbind(summary.beta, rep(n.keep, p), rep(100,p), effectiveSize(samples.beta.orig), geweke.diag(samples.beta.orig)$z)
 rownames(summary.beta) <- colnames(X)
-colnames(summary.beta) <- c("Median", "2.5%", "97.5%", "n.sample", "% accept", "n.effective", "Geweke.diag")
+colnames(summary.beta) <- c("Mean", "2.5%", "97.5%", "n.sample", "% accept", "n.effective", "Geweke.diag")
 
-summary.hyper <- array(NA, c(4 ,7))
-summary.hyper[1, 1:3] <- quantile(samples.nu2, c(0.5, 0.025, 0.975))
+summary.hyper <- array(NA, c(3 ,7))
+summary.hyper[1, 1:3] <- c(mean(samples.nu2), quantile(samples.nu2, c(0.025, 0.975)))
 summary.hyper[1, 4:7] <- c(n.keep, 100, effectiveSize(samples.nu2), geweke.diag(samples.nu2)$z)
-summary.hyper[2, 1:3] <- quantile(samples.tau2, c(0.5, 0.025, 0.975))
+summary.hyper[2, 1:3] <- c(mean(samples.tau2), quantile(samples.tau2, c(0.025, 0.975)))
 summary.hyper[2, 4:7] <- c(n.keep, 100, effectiveSize(samples.tau2), geweke.diag(samples.tau2)$z)
-    if(!is.null(ind.re))
-    {
-    summary.hyper[3, 1:3] <- quantile(samples.sigma2, c(0.5, 0.025, 0.975))
-    summary.hyper[3, 4:7] <- c(n.keep, 100, effectiveSize(samples.sigma2), geweke.diag(samples.sigma2)$z)
-    }else
-    {
-    summary.hyper[3, ] <- rep(NA, 7)   
-    }
-    
     if(!fix.rho)
     {
-    summary.hyper[4, 1:3] <- quantile(samples.rho, c(0.5, 0.025, 0.975))
-    summary.hyper[4, 4:7] <- c(n.keep, accept.rho, effectiveSize(samples.rho), geweke.diag(samples.rho)$z)
+    summary.hyper[3, 1:3] <- c(mean(samples.rho), quantile(samples.rho, c(0.025, 0.975)))
+    summary.hyper[3, 4:7] <- c(n.keep, accept.rho, effectiveSize(samples.rho), geweke.diag(samples.rho)$z)
     }else
     {
-    summary.hyper[4, 1:3] <- c(rho, rho, rho)
-    summary.hyper[4, 4:7] <- rep(NA, 4)
+    summary.hyper[3, 1:3] <- c(rho, rho, rho)
+    summary.hyper[3, 4:7] <- rep(NA, 4)
     }
 
 summary.results <- rbind(summary.beta, summary.hyper)
-rownames(summary.results)[(nrow(summary.results)-3):nrow(summary.results)] <- c("nu2", "tau2", "sigma2", "rho")
+rownames(summary.results)[(nrow(summary.results)-2):nrow(summary.results)] <- c("nu2", "tau2", "rho")
 summary.results[ , 1:3] <- round(summary.results[ , 1:3], 4)
 summary.results[ , 4:7] <- round(summary.results[ , 4:7], 1)
-    if(is.null(ind.re)) summary.results <- summary.results[-(nrow(summary.results)-1), ]   
-    
+
 
 #### Create the Fitted values and residuals
 fitted.values <- apply(samples.fitted, 2, mean)
@@ -471,19 +386,11 @@ residuals <- data.frame(response=response.residuals, pearson=pearson.residuals)
 
     
 #### Compile and return the results
-    if(is.null(ind.re))
-    {
-    model.string <- c("Likelihood model - Gaussian (identity link function)", "\nRandom effects model - Multilevel Leroux CAR\n")
-    }else
-    {
-    model.string <- c("Likelihood model - Gaussian (identity link function)", "\nRandom effects model - Multilevel Leroux CAR with factor random effects\n")
-    }
+model.string <- c("Likelihood model - Gaussian (identity link function)", "\nRandom effects model - Multilevel Leroux CAR\n")
     if(fix.rho) samples.rho=NA
     if(n.miss==0) samples.Y = NA
-    if(is.null(ind.re)) samples.sigma2 = NA    
-    if(is.null(ind.re)) samples.psi = NA  
 
-samples <- list(beta=samples.beta.orig, phi=mcmc(samples.phi), zeta=mcmc(samples.psi), tau2=mcmc(samples.tau2), sigma2=mcmc(samples.sigma2), nu2=mcmc(samples.nu2), rho=mcmc(samples.rho), fitted=mcmc(samples.fitted), Y=mcmc(samples.Y))
+samples <- list(beta=samples.beta.orig, phi=mcmc(samples.phi), tau2=mcmc(samples.tau2), nu2=mcmc(samples.nu2), rho=mcmc(samples.rho), fitted=mcmc(samples.fitted), Y=mcmc(samples.Y))
 results <- list(summary.results=summary.results, samples=samples, fitted.values=fitted.values, residuals=residuals, modelfit=modelfit, accept=accept.final, localised.structure=NULL,  formula=formula, model=model.string, X=X)
 class(results) <- "CARBayes"
     
